@@ -9,7 +9,7 @@ use Attribute::Handlers;
 
 use Lexical::Failure::Objects;
 
-our $VERSION = '0.001000';
+our $VERSION = '0.001001';
 
 # Be invisible to Carp...
 our @CARP_NOT = __PACKAGE__;
@@ -20,8 +20,10 @@ my $HINTS = 10;
 # How to fail...
 my %STD_FAILURE_HANDLERS = (
     'die'     => sub { _uplevel_die(@_);                      },
-    'croak'   => sub { package Carp; uplevel { croak(@_)   } @_, CALLER($Lexical::Failure::uplevel); },
-    'confess' => sub { package Carp; uplevel { confess(@_) } @_, CALLER($Lexical::Failure::uplevel); },
+    'croak'   => sub { package # Hide this from CPAN indexer
+                       Carp; uplevel { croak(@_)   } @_, CALLER($Lexical::Failure::uplevel); },
+    'confess' => sub { package # Hide this from CPAN indexer
+                       Carp; uplevel { confess(@_) } @_, CALLER($Lexical::Failure::uplevel); },
     'null'    => sub { return;                                },
     'undef'   => sub { return undef;                          },
 
@@ -208,7 +210,7 @@ sub fail {
 
     # Ignore this code when croaking/carping from a handler
     package
-    Carp;
+    Carp; # Hide this from CPAN indexer
     use Scope::Upper qw< unwind CALLER UP SUB>;
 
     # Simulate a return...
@@ -280,7 +282,7 @@ Lexical::Failure - User-selectable lexically-scoped failure signaling
 
 =head1 VERSION
 
-This document describes Lexical::Failure version 0.001000
+This document describes Lexical::Failure version 0.001001
 
 
 =head1 SYNOPSIS
