@@ -1,4 +1,5 @@
-package ExtrasModule;
+package
+ExtrasModule;
 our $VERSION = '0.000001';
 
 use 5.014;
